# aigve.metrics

:::aigve.metrics

---------------------------------------
## Organization of this Module

### Neural Network-Based Evaluation Metrics
* [GSTVQA](gstvqa.md)
* [SimpleVQA](simplevqa.md)
* [ModularBVQA](modular_bvqa.md)

### Distribution-Based Evaluation Metricsn Metrics
* [FID](fid.md)
* [FVD](fvd.md)
* [IS Score](is_score.md) 

### Vision-Language Similarity-Based Evaluation Metrics Metrics
* [CLIPSim](clipsim.md)
* [CLIPTemp](cliptemp.md)
* [BLIPSim](blipsim.md)
* [Pickscore](pickscore.md)

### Vision-Language Understanding-Based Evaluation Metrics
* [VIEScore](viescore.md)
* [TIFA](tifa.md)
* [DSG](dsg.md)

### Multi-Faceted Evaluation Metrics
* [VideoPhy](videophy.md)
* [VBench](vbench.md)
* [EvalCrafter](eval_crafter.md)